pub struct ExecutionPolicy<C, T, E> { /* private fields */ }Expand description
A reusable reliability policy. Cheap to clone (shares a compiled Plan).
Implementations
Sourceimpl ExecutionPolicy<(), (), ()>
impl ExecutionPolicy<(), (), ()>
Sourcepub fn builder<T, E>() -> ExecutionPolicyBuilder<T, E>
pub fn builder<T, E>() -> ExecutionPolicyBuilder<T, E>
Start configuring a policy. The T/E types are inferred at the first
retry(..) or execute call site.
Sourceimpl<C, T, E> ExecutionPolicy<C, T, E>
impl<C, T, E> ExecutionPolicy<C, T, E>
Sourcepub fn circuit_state(&self) -> Option<BreakerState>
pub fn circuit_state(&self) -> Option<BreakerState>
Current circuit-breaker state, or None if no breaker is configured.
Sourceimpl<C, T, E> ExecutionPolicy<C, T, E>where
C: Core,
impl<C, T, E> ExecutionPolicy<C, T, E>where
C: Core,
Sourcepub async fn run<F>(&self, op: F) -> Result<T, ExecutionError<E>>where
F: AsyncFnMut() -> Result<T, E>,
pub async fn run<F>(&self, op: F) -> Result<T, ExecutionError<E>>where
F: AsyncFnMut() -> Result<T, E>,
Run an operation that needs neither application state nor attempt metadata.
Sourcepub async fn execute<F>(&self, op: F) -> Result<T, ExecutionError<E>>
pub async fn execute<F>(&self, op: F) -> Result<T, ExecutionError<E>>
Run an operation that wants attempt metadata.
Sourcepub async fn run_with<S, F>(
&self,
state: &S,
op: F,
) -> Result<T, ExecutionError<E>>
pub async fn run_with<S, F>( &self, state: &S, op: F, ) -> Result<T, ExecutionError<E>>
Run an operation with injected application state.
Sourcepub async fn execute_with<S, F>(
&self,
state: &S,
op: F,
) -> Result<T, ExecutionError<E>>
pub async fn execute_with<S, F>( &self, state: &S, op: F, ) -> Result<T, ExecutionError<E>>
Run an operation with injected state and attempt metadata.