Module retry

Module retry 

Retry policy, backoff schedules, and jitter.

Re-exports

pub use backoff::Backoff;
pub use budget::RetryBudget;
pub use jitter::Jitter;

Modules

backoff
budget
Shared retry budget: a lock-free token bucket that bounds retries to a fraction of total traffic, protecting dependencies from retry storms.
jitter

Structs

Retry
Retry configuration: attempt cap, backoff, jitter, classification, budget.